@@ -115,6 +115,9 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #define OPT_CATEGORIES       "list-cat"  
 #define OPT_PIPED_FNAME      "syntax-by-name"
 #define OPT_ISOLATE_TAGS     "isolate"
+#define OPT_MAX_FILE_SIZE    "max-size"
+//#define OPT_TWO_PASS         "two-pass"
+
 
 // Improve CLI option compatibility with GNU source-highlight
 #define OPT_COMPAT_DOC       "doc"
@@ -322,6 +325,9 @@ public:
     /** \return True if output token of the same syntax category should be in separate tags */
     bool isolateTags() const;
     
+    /** \return max. input file size (default 256 MB) */
+    off_t getMaxFileSize() const;
+    
     /** \return The given base font, empty string by default */
     const string& getBaseFont() const ;
 
@@ -369,6 +375,9 @@ public:
 
     /** \return category of scripts which should be listed */
     const string& getListScriptKind() const;
+    
+        /** \return fallback syntax if not defined or found by filename or shebang */
+    const string& getFallbackSyntax() const;
 
     /** \return line number width */
     int getNumberWidth();
@@ -436,7 +445,7 @@ private:
     string docTitle, className;
     string skipArg;
     string svg_height, svg_width;
-    string absThemePath, absLangPath;
+    string absThemePath, absLangPath/*, twoPassFile*/;
 
     bool opt_syntax;
     bool opt_include_style;
@@ -475,8 +484,10 @@ private:
     bool opt_no_version_info;
     bool explicit_output_format;
     bool opt_isolate;
+    
+    off_t maxFileSize;
 
-    string anchorPrefix;
+    string fallbackSyntax, anchorPrefix;
     string helpLang, encodingName;
 
     string pluginPath, pluginParameter, 
