@@ -135,11 +135,13 @@ void printHelp(const std::string &topic)
         cout<<"     --syntax-by-name=<name>    specify type of source code by given name\n";
         cout<<"                                  will not read a file of this name, useful for stdin\n";
         cout<<" -v, --verbose                  print debug info\n";
-        cout<<"     --force                    generate output if input syntax is unknown\n";
+        cout<<"     --force[=syntax]           generate output if input syntax is unknown\n";
         cout<<"     --list-scripts=<type>      list installed scripts\n";
         cout<<"                                  <type> = [langs, themes, plugins]\n";
         cout<<"     --list-cat=<categories>    filter the scripts by the given categories\n"; 
         cout<<"                                  (example: --list-cat='source;script')\n";
+        cout<<"     --max-size=<size>          set maximum input file size\n";
+        cout<<"                                  (examples: 512M, 1G; default: 256M)\n"; 
         cout<<"     --plug-in=<script>         execute Lua plug-in script; repeat option to\n";
         cout<<"                                  execute multiple plug-ins\n";
         cout<<"     --plug-in-param=<value>    set plug-in input parameter\n";
@@ -201,6 +203,9 @@ void printHelp(const std::string &topic)
         cout<<"                                  <case> =  [upper, lower, capitalize]\n";
         cout<<"     --no-trailing-nl           omit trailing newline\n";
         cout<<"     --no-version-info          omit version info comment\n";
+       // cout<<"     --two-pass=<file>          write plug-in with persistent state information\n";
+       // cout<<"                                  (beta; requires syntax with store instructions)\n";
+        
         cout<<"\n\n";
         cout<<"(X)HTML output options:\n";
         cout<<"\n";
