@@ -292,13 +292,22 @@ void HLCmdLineApp::printCurrentAction ( const string&outfilePath,
 
 void HLCmdLineApp::printIOErrorReport ( unsigned int numberErrorFiles,
                                         vector<string> & fileList,
-                                        const string &action )
+                                        const string &action, const string &streamName  )
 {
+    
+    
     cerr << "highlight: Could not "
          << action
          << " file"
          << ( ( numberErrorFiles>1 ) ?"s":"" ) <<":\n";
-    copy ( fileList.begin(), fileList.end(), ostream_iterator<string> ( cerr, "\n" ) );
+    
+    if (numberErrorFiles==1 && fileList[0].size()==0){
+        cerr<<streamName<<"\n";
+    }
+    else {
+        copy ( fileList.begin(), fileList.end(), ostream_iterator<string> ( cerr, "\n" ) );
+    }
+    
     if ( fileList.size() < numberErrorFiles ) {
         cerr << "... ["
              << ( numberErrorFiles - fileList.size() )
@@ -489,7 +498,7 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
     dirTest.close();
 #endif
 
-    bool initError=false, IOError=false;
+    bool initError=false, IOError=false, twoPassMode=false;
     unsigned int fileCount=inFileList.size(),
                  fileCountWidth=getNumDigits ( fileCount ),
                  i=0,
@@ -501,10 +510,9 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
     std::set<string> usedFileNames;
     string inFileName, outFilePath;
     string suffix, lastSuffix;
-
+    string twoPassOutFile=Platform::getTempFilePath();
+    
     if ( options.syntaxGiven() ) { // user defined language definition, valid for all files
-        //TODO check for filename given prior to IO redirection
-        //--syntax-by-name overrides --syntax
         string syntaxByFile=options.getSyntaxByFilename();
         string testSuffix = syntaxByFile.empty() ? options.getSyntax() : dataDir.getFileSuffix(syntaxByFile); 
         suffix = dataDir.guessFileType (testSuffix, syntaxByFile, syntaxByFile.empty(), true );         
@@ -513,11 +521,33 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
     generator->setFilesCnt(fileCount);
         
     while ( i < fileCount && !initError ) {
-           
+        
+        if ( Platform::fileSize(inFileList[i]) > options.getMaxFileSize() ) {
+            
+            if ( numBadInput++ < IO_ERROR_REPORT_LENGTH || options.printDebugInfo() ) {
+                badInputFiles.push_back ( inFileList[i] + " (size)" );
+            }
+            ++i;
+            continue;
+        }
+        
+        if (i==0 && twoPassMode) {
+             if ( !generator->initPluginScript(twoPassOutFile) ) {
+                cerr << "highlight: "
+                 << generator->getPluginScriptError()
+                 << " in "
+                 << twoPassOutFile
+                 <<"\n";
+                initError = true;
+                break;
+            }
+        }
+    
         if ( !options.syntaxGiven() ) { // determine file type for each file
             suffix = dataDir.guessFileType ( dataDir.getFileSuffix ( inFileList[i] ), inFileList[i] );
         }
-        if ( suffix.empty()  && options.forceOutput()) suffix="txt"; //avoid segfault
+        
+        if ( suffix.empty()  && options.forceOutput()) suffix=options.getFallbackSyntax(); //avoid segfault
         if ( suffix.empty() ) {
             if ( !options.enableBatchMode() )
                 cerr << "highlight: Undefined language definition. Use --"
@@ -529,7 +559,7 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
         }
 
         if ( suffix != lastSuffix ) {
-        
+            
             string langDefPath=options.getAbsLangPath().empty() ? dataDir.getLangPath ( suffix+".lang" ) : options.getAbsLangPath();
 
             highlight::LoadResult loadRes= generator-> loadLanguage( langDefPath );
@@ -566,6 +596,11 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
             lastSuffix = suffix;
         }
 
+        if (twoPassMode && !generator->syntaxRequiresTwoPassRun()) {
+            ++i;
+            continue;
+        }
+        
         string::size_type pos= ( inFileList[i] ).find_last_of ( Platform::pathSeparator );
         inFileName = inFileList[i].substr ( pos+1 );
 
@@ -623,7 +658,30 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
                 badFormattedFiles.push_back ( outFilePath );
             }
         }
+        
         ++i;
+        
+        if (i==fileCount && outFilePath.size() && generator->requiresTwoPassParsing() && twoPassOutFile.size() 
+            && !numBadInput && !numBadOutput && !twoPassMode) {
+            
+            bool success=generator->printPersistentState(twoPassOutFile);
+            if ( !success ) {
+                cerr << "highlight: Could not write "<< twoPassOutFile <<".\n";
+                IOError = true;
+            } else {
+                twoPassMode=true;
+                if ( !options.quietMode() &&  !options.forceStdout() ) {
+                    cout << "Enabling two-pass mode using "<<twoPassOutFile<<"\n";
+                }
+                //start over, add plug-in to list in next iteration
+                usedFileNames.clear();
+                generator->resetSyntaxReaders();
+                i=0;
+                lastSuffix.clear();
+                numBadFormatting=0;
+                badFormattedFiles.clear();    
+            }
+        }
     }
 
     if ( i  && !options.includeStyleDef()
@@ -645,24 +703,29 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
             IOError = true;
         }
     }
-
+    
     if ( numBadInput ) {
-        printIOErrorReport ( numBadInput, badInputFiles, "read input" );
+        printIOErrorReport ( numBadInput, badInputFiles, "read input", "<stdin>" );
         IOError = true;
     }
     if ( numBadOutput ) {
-        printIOErrorReport ( numBadOutput, badOutputFiles, "write output" );
+        printIOErrorReport ( numBadOutput, badOutputFiles, "write output",  "<stdout>" );
         IOError = true;
     }
     if ( numBadFormatting ) {
-        printIOErrorReport ( numBadFormatting, badFormattedFiles, "reformat" );
+        printIOErrorReport ( numBadFormatting, badFormattedFiles, "reformat", "<stdout>" );
     }
     
     vector<string> posTestErrors = generator->getPosTestErrors();
     if (posTestErrors.size()){
         IOError = true;
-        printIOErrorReport ( posTestErrors.size(), posTestErrors, "validate" );
+        printIOErrorReport ( posTestErrors.size(), posTestErrors, "validate", "<stdin>" );
     }
+    
+    if (twoPassMode) {
+        unlink(twoPassOutFile.c_str());
+    }
+        
     return ( initError || IOError ) ? EXIT_FAILURE : EXIT_SUCCESS;
 }
 
