@@ -128,6 +128,7 @@ CodeGenerator::CodeGenerator ( highlight::OutputType type )
      printNewLines(true),
      omitVersionComment(false),
      isolateTags(false),
+     disableStyleCache(false),
      baseFontSize("10"),
      lineNumber ( 0 ),
      lineNumberOffset ( 0 ),
@@ -166,9 +167,7 @@ CodeGenerator::~CodeGenerator()
 {
     delete formatter;
 
-    for ( map<string, SyntaxReader*>::iterator it=syntaxReaders.begin(); it!=syntaxReaders.end(); it++ ) {
-        delete it->second;
-    }
+    resetSyntaxReaders();
     
     for (unsigned int i=0; i<pluginChunks.size(); i++) {
         delete pluginChunks[i];
@@ -388,6 +387,7 @@ void CodeGenerator::setMaxInputLineCnt ( unsigned int cnt )
 void CodeGenerator::setFilesCnt ( unsigned int cnt )
 {
     inputFilesCnt = cnt;
+    processedFilesCnt = 0;
 }
 
 bool CodeGenerator::formattingIsPossible()
@@ -434,11 +434,18 @@ void CodeGenerator::reset()
     syntaxChangeIndex = syntaxChangeLineNo = UINT_MAX;
     startLineCntCurFile = startLineCnt;
     applySyntaxTestCase=lineContainedTestCase=false;
+    if (currentSyntax){
+        vector<int> overrideStyleAttrs=currentSyntax->getOverrideStyleAttributes();
+        docStyle.overrideAttributes(overrideStyleAttrs);
+        if (overrideStyleAttrs.size())
+            disableStyleCache = true;    
+    }
+    
 }
 
 string CodeGenerator::getThemeInitError()
 {
-    return  docStyle.getErrorMessage();
+    return docStyle.getErrorMessage();
 }
 
 string CodeGenerator::getPluginScriptError()
@@ -516,16 +523,37 @@ void CodeGenerator::matchRegex ( const string &line, State skipState)
         RegexElement *regexElem = currentSyntax->getRegexElements() [i];
 
         if (regexElem->open == skipState) continue;
+
+        if (regexElem->constraintLineNum && regexElem->constraintLineNum != lineNumber) {
+            continue;
+        }
         
+        if (regexElem->constraintFilename.size() && regexElem->constraintFilename != inFile) {
+            continue;
+        }
+
         boost::xpressive::sregex_iterator cur( line.begin(), line.end(), regexElem->rex );
         boost::xpressive::sregex_iterator end;
 
         for( ; cur != end; ++cur )  {
             groupID = ( regexElem->capturingGroup<0 ) ? cur->size()-1 : regexElem->capturingGroup;
-            matchBegin =  cur->position(groupID);
+            matchBegin = cur->position(groupID);
+        
             regexGroups.insert (
                 make_pair ( matchBegin + 1, ReGroup ( regexElem->open, cur->length(groupID), regexElem->kwClass, regexElem->langName ) ) );
+            
+            //Only return first match
+            //if (regexElem->kwClass==6)
+              //  break;
+
+            // priority regex (match required)
+            if (regexElem->priority) {
+                return;
+            }
+
         }
+        
+        // prio check here if match not necessary
     }
 }
 
@@ -637,7 +665,7 @@ SKIP_EMBEDDED:
 
             if ( regexGroups[oldIndex].state==IDENTIFIER_BEGIN || regexGroups[oldIndex].state==KEYWORD ) {
                 string reservedWord= ( currentSyntax->isIgnoreCase() ) ? StringTools::change_case ( token ) :token;
-                currentKeywordClass=currentSyntax->isKeyword ( reservedWord ); //check in lists (no regex)
+                currentKeywordClass=currentSyntax->getKeywordListGroup ( reservedWord ); //check in lists (no regex)
                 
                 if ( !currentKeywordClass && regexGroups[oldIndex].state==KEYWORD ){
                     currentKeywordClass = regexGroups[oldIndex].kwClass;
@@ -720,7 +748,9 @@ void CodeGenerator::maskString ( ostream& ss, const string & s )
     for ( unsigned int i=0; i< s.length(); i++ ) {
         ss << maskCharacter ( s[i] );
 
-        if (applySyntaxTestCase) {
+        // do not add a trace indicator state for each byte of a UTF-8 sequence, only for the seq start
+        // https://stackoverflow.com/questions/4063146/getting-the-actual-length-of-a-utf-8-encoded-stdstring
+        if (applySyntaxTestCase && (s[i] & 0xc0) != 0x80 ) {
             PositionState ps(currentState, getCurrentKeywordClassId(), false);
             stateTraceCurrent.push_back(ps);
             
@@ -1284,7 +1314,6 @@ LoadResult CodeGenerator::loadLanguage ( const string& langDefPath, bool embedde
     
     bool reloadNecessary= currentSyntax ? currentSyntax->needsReload ( langDefPath ): true;
     LoadResult result=LOAD_OK;
-
     if ( reloadNecessary ) {
         if (syntaxReaders.count(langDefPath)) {
             currentSyntax=syntaxReaders[langDefPath];
@@ -1384,7 +1413,7 @@ bool CodeGenerator::validateInputStream()
 
 void CodeGenerator::applyPluginChunk(const string& fctName, string *result, bool *keepDefault) {
     
-    if ( pluginChunks.size()) {
+    if (currentSyntax && pluginChunks.size()) {
     
         Diluculum::LuaState luaState;
 
@@ -1411,7 +1440,7 @@ void CodeGenerator::applyPluginChunk(const string& fctName, string *result, bool
             luaState["HL_FORMAT_BBCODE"]=BBCODE;
             luaState["HL_FORMAT_PANGO"]=PANGO;
             luaState["HL_FORMAT_ODT"]=ODTFLAT;
-            
+                        
             Diluculum::LuaValueList params;
             Diluculum::LuaValueMap options;
             options[Diluculum::LuaValue("title")] =  Diluculum::LuaValue( docTitle );   
@@ -1505,6 +1534,7 @@ ParseError CodeGenerator::generateFile ( const string &inFileName,
         if ( formatter != NULL ) {
             formatter->init ( new astyle::ASStreamIterator ( in ) );
         }
+        currentSyntax->setInputFileName(inFile);
         printHeader();
         printBody();
         printFooter();
@@ -1579,6 +1609,8 @@ string CodeGenerator::generateStringFromFile ( const string &inFileName )
     if ( formatter != NULL ) {
         formatter->init ( new astyle::ASStreamIterator ( in ) );
     }
+    currentSyntax->setInputFileName(inFile);
+    
     printHeader();
     printBody();
     printFooter();
@@ -2355,6 +2387,7 @@ void CodeGenerator::printTrace(const string &s){
     std::cout<<"\n";
 }
 
+//column: lineIndex (not a UTF-8 validated string position)
 void CodeGenerator::runSyntaxTestcases(unsigned int column){
     
     unsigned int assertGroup=0;
@@ -2501,6 +2534,12 @@ unsigned int CodeGenerator::getLastLineLength()
     return lastLineLength;
 }
 
+bool CodeGenerator::requiresTwoPassParsing() const {
+    if (!currentSyntax) return false;
+    return currentSyntax->getPersistentSnippetsNum()>0;
+}
+
+
 bool CodeGenerator::printExternalStyle ( const string &outFile )
 {
     if ( !includeStyleDef ) {
@@ -2523,6 +2562,35 @@ bool CodeGenerator::printExternalStyle ( const string &outFile )
     return true;
 }
 
+bool CodeGenerator::printPersistentState ( const string &outFile )
+{
+    if (!currentSyntax) return false;
+
+    ofstream pluginOutFile( outFile.c_str());
+    if ( !pluginOutFile.fail() ) {
+        
+        pluginOutFile   <<"Description=\"Plugin generated by highlight using the --two-pass option\"\n\n"
+                        <<"Categories = {\"two-pass\" }\n\n"
+                        <<"function syntaxUpdate(desc)\n\n";
+                        
+        pluginOutFile << currentSyntax->getPersistentHookConditions();
+     
+        for (auto snippet: currentSyntax->getPersistentSnippets())
+        {   
+            pluginOutFile << snippet <<"\n\n";
+        }
+        
+        pluginOutFile<<"end\n\n"
+                     <<"Plugins={\n"
+                     <<"  { Type=\"lang\", Chunk=syntaxUpdate }\n"
+                     <<"}\n";
+    } else {
+        return false;
+    }
+    
+    return true;
+}
+
 string CodeGenerator::readUserStyleDef()
 {
     ostringstream ostr;
@@ -2596,4 +2664,24 @@ bool CodeGenerator::initPluginScript(const string& script)
     return true;
 }
 
+void CodeGenerator::resetSyntaxReaders() {
+    for ( map<string, SyntaxReader*>::iterator it=syntaxReaders.begin(); it!=syntaxReaders.end(); it++ ) {
+        delete it->second;
+    }
+    currentSyntax=NULL;
+    syntaxReaders.clear();
+}
+
+bool CodeGenerator::syntaxRequiresTwoPassRun() {
+    if (!currentSyntax) return false;
+    return currentSyntax->requiresTwoPassRun();
+}
+
+void CodeGenerator::clearPersistentSnippets(){
+    if (currentSyntax) {
+        currentSyntax->clearPersistentSnippets();
+    }
+}
+
+
 }
