@@ -50,6 +50,11 @@ AllowInnerSectionsMap SyntaxReader::allowInnerSections;
 
 vector<Diluculum::LuaFunction*> SyntaxReader::pluginChunks;
 
+vector<string> SyntaxReader::persistentSnippets;
+
+set<string> SyntaxReader::persistentSyntaxDescriptions;
+
+
 int RegexElement::instanceCnt=0;
 
 
@@ -139,7 +144,7 @@ void  SyntaxReader::initLuaState(Diluculum::LuaState& ls, const string& langDefP
     ls["HL_FORMAT_BBCODE"]=BBCODE;
     ls["HL_FORMAT_PANGO"]=PANGO;
     ls["HL_FORMAT_ODT"]=ODTFLAT;
-    
+
     // default values for --verbose
     ls["IgnoreCase"]=false;
     ls["EnableIndentation"]=false;
@@ -163,8 +168,9 @@ LoadResult SyntaxReader::load ( const string& langDefPath, const string& pluginR
         Diluculum::LuaState& ls=*luaState;
         initLuaState(ls, langDefPath, pluginReadFilePath, outputType);
 
-        lua_register (ls.getState(),"AddKeyword",luaAddKeyword);
-        lua_register (ls.getState(),"RemoveKeyword",luaRemoveKeyword);
+        lua_register (ls.getState(), "AddKeyword", luaAddKeyword);
+        lua_register (ls.getState(), "RemoveKeyword", luaRemoveKeyword);
+        lua_register (ls.getState(), "AddPersistentState", luaAddPersistentState);
 
         SyntaxReader **s = (SyntaxReader **)lua_newuserdata(ls.getState(), sizeof(SyntaxReader *));
         *s=this;
@@ -207,7 +213,7 @@ LoadResult SyntaxReader::load ( const string& langDefPath, const string& pluginR
         int kwId=0;
         while (ls["Keywords"][idx].value() !=Diluculum::Nil) {
             kwId= generateNewKWClass ( ls["Keywords"][idx]["Id"].value().asInteger() );
-
+            
             if (ls["Keywords"][idx]["List"].value()!=Diluculum::Nil) {
                 int listIdx=1;
                 Diluculum::LuaVariable luaList=ls["Keywords"][idx]["List"];
@@ -221,7 +227,26 @@ LoadResult SyntaxReader::load ( const string& langDefPath, const string& pluginR
                 if (ls["Keywords"][idx]["Group"].value()!=Diluculum::Nil) {
                     captGroup=ls["Keywords"][idx]["Group"].value().asInteger();
                 }
-                regex.push_back ( new RegexElement ( KEYWORD, KEYWORD_END, reString, kwId, captGroup ) );
+
+                unsigned int priority=0;
+                if (ls["Keywords"][idx]["Priority"].value()!=Diluculum::Nil) {
+                    priority=ls["Keywords"][idx]["Priority"].value().asInteger();
+                }
+                
+                //string semantics;
+                //if (ls["Keywords"][idx]["Semantics"].value()!=Diluculum::Nil)
+                //         constraintFilename =ls["Keywords"][idx]["Semantics"].value().asString();
+                
+                unsigned int constraintLineNum=0;
+                string constraintFilename, semanticDescription;
+                if (ls["Keywords"][idx]["Constraints"].value()!=Diluculum::Nil) {
+
+                    if (ls["Keywords"][idx]["Constraints"]["Line"].value()!=Diluculum::Nil)
+                        constraintLineNum=ls["Keywords"][idx]["Constraints"]["Line"].value().asInteger();
+                    if (ls["Keywords"][idx]["Constraints"]["Filename"].value()!=Diluculum::Nil)
+                        constraintFilename =ls["Keywords"][idx]["Constraints"]["Filename"].value().asString();
+                }
+                regex.push_back ( new RegexElement ( KEYWORD, KEYWORD_END, reString, kwId, captGroup, "", priority, constraintLineNum,  constraintFilename ) );
             }
             idx++;
         }
@@ -236,6 +261,29 @@ LoadResult SyntaxReader::load ( const string& langDefPath, const string& pluginR
             }
         }
         
+        if (globals.count("KeywordFormatHints")) {
+            idx=1;
+            Diluculum::LuaValue lVal = ls["KeywordFormatHints"][idx].value();
+            while (lVal !=Diluculum::Nil) {
+                
+                int kwStyleOverride = lVal["Id"].asInteger();
+
+                if (lVal["Bold"]!=Diluculum::Nil){
+                    kwStyleOverride += lVal["Bold"].asBoolean() ? 128 : 1024;
+                }
+                if (lVal["Italic"]!=Diluculum::Nil){
+                     kwStyleOverride += lVal["Italic"].asBoolean() ? 256 : 2048;
+                }
+                if (lVal["Underline"]!=Diluculum::Nil){
+                    kwStyleOverride += lVal["Underline"].asBoolean() ? 512 : 4096;
+                }
+                 
+                overrideStyles.push_back(kwStyleOverride);
+                idx++;
+                lVal = ls["KeywordFormatHints"][idx].value();
+            }
+        }
+        
         if (globals.count("Comments")) {
 
             int listIdx=1;
@@ -415,11 +463,18 @@ void SyntaxReader::removeKeyword(const string& kw)
     keywords.erase(kw);
 }
 
-int SyntaxReader::isKeyword ( const string &s )
+bool SyntaxReader::isKeyword ( const string &s )
 {
-    return ( s.length() && keywords.count ( s ) ) ? keywords[s] : 0;
+    return ( s.length() && keywords.count ( s ) ) ;
 }
 
+int SyntaxReader::getKeywordListGroup ( const string &s ) {
+    if (isKeyword(s)) {
+        return keywords[s];
+    }
+    return 0;
+}
+    
 int SyntaxReader::luaAddKeyword (lua_State *L)
 {
     int retVal=0;
@@ -528,4 +583,85 @@ bool SyntaxReader::matchesOpenDelimiter ( const string& token, State s, int open
     return false;
 }
 
+void SyntaxReader::addPersistentKeyword(unsigned int groupID, const string& kw){
+    ostringstream expr;
+    expr <<"AddKeyword(\""<<kw<<"\", "<<groupID<<")";
+             
+    persistentSnippets.push_back(expr.str());
+    persistentSyntaxDescriptions.insert(langDesc);
+}
+    
+void SyntaxReader::addPersistentStateRange(unsigned int groupID, unsigned int column,unsigned int length, unsigned int lineNumber, const string& fileName){
+    ostringstream expr;
+    expr <<"table.insert(Keywords,\n"
+         << "{ Id="<<groupID<<",\n"
+         <<"  Regex=[[^.{"<<column<<"}(.{"<<length<<"})]],\n"
+         <<"  Priority=1,\n"
+         <<"  Constraints = {\n"
+         <<"    Line = "<<lineNumber<<",\n"
+         <<"    Filename = \""<<fileName<<"\",\n"
+         <<" }\n"
+         <<"})";
+                
+    persistentSnippets.push_back(expr.str());
+    persistentSyntaxDescriptions.insert(langDesc);
+}
+
+string SyntaxReader::getPersistentHookConditions() {
+    ostringstream expr;
+    expr << "ValidDesc = {";
+    
+    for (auto desc: persistentSyntaxDescriptions) {
+        expr << "\"" << desc << "\",";
+    }
+    
+    expr << "}\nif ValidDesc[desc] ~= nil then return end\n\n";
+    
+    return expr.str();
+    
+}
+ 
+int SyntaxReader::luaAddPersistentState (lua_State *L)
+{
+    int retVal=0;
+    if (lua_gettop(L)==2) {
+        const char*keyword=lua_tostring(L, 1);
+        unsigned int kwgroupID=lua_tonumber(L, 2);
+        lua_getglobal(L, GLOBAL_SR_INSTANCE_NAME);
+        SyntaxReader **a=reinterpret_cast<SyntaxReader **>(lua_touserdata(L, 3));
+        if (*a) {
+            if (!(*a)->isKeyword(keyword)) {
+                (*a)->addKeyword(kwgroupID, keyword);
+                (*a)->addPersistentKeyword(kwgroupID, keyword);
+            }
+            
+            retVal=1;
+        }
+    }
+    if (lua_gettop(L)==4) {
+        unsigned int lineNumber=lua_tonumber(L, 1);
+        unsigned int kwgroupID=lua_tonumber(L, 2);
+        unsigned int column=lua_tonumber(L, 3);
+        unsigned int length=lua_tonumber(L, 4);
+        lua_getglobal(L, GLOBAL_SR_INSTANCE_NAME);
+        SyntaxReader **a=reinterpret_cast<SyntaxReader **>(lua_touserdata(L, 5));
+        if (*a) {
+            (*a)->addPersistentStateRange(kwgroupID, column, length, lineNumber, (*a)->getInputFileName() );
+            retVal=1;
+        }
+    }
+    lua_pushboolean(L, retVal);
+    return 1;
+} 
+
+bool SyntaxReader::requiresTwoPassRun(){
+    return persistentSyntaxDescriptions.count(langDesc)>0;
+}
+
+void SyntaxReader::clearPersistentSnippets() {
+    persistentSyntaxDescriptions.clear();
+    persistentSnippets.clear();
+}
+
+
 }
