@@ -4,7 +4,7 @@
                              -------------------
     begin                : Mo 16.03.2009
     copyright            : (C) 2009-2017 by Andre Simon
-    email                : andre.simon1@gmx.de
+    email                : a.simon@mailbox.org
  ***************************************************************************/
 
 /*
@@ -72,6 +72,13 @@ bool ShowTextFile::setFileName(const QString& fileName)
     return file.exists();
 }
 
+void ShowTextFile::setText(const QString& content, const QString& title)
+{
+   m_ui->textBrowser->setText( content );
+   m_ui->lbTitle->setText(title);
+}
+
+
 void ShowTextFile::on_pushButton_clicked()
 {
     this->close();
