@@ -222,6 +222,12 @@ public:
       */
     bool printExternalStyle ( const string &outFile );
 
+        /** Print persistent state snippets to external file 
+      \param outFile Path of plugin file to generate
+       \return true if successfull
+      */
+    bool printPersistentState ( const string &outFile );
+    
     /** Print index file with all input file names
        \param fileList List of output file names
        \param outPath Output path
@@ -279,7 +285,7 @@ public:
 
     /** \return line number width */
     int getLineNumberWidth();
-
+    
     /** check if input is binary or text
        \param  flag true if input should be checked
     */
@@ -296,6 +302,8 @@ public:
 
     /** \return keep injection flag */
     bool getKeepInjections();
+    
+    bool requiresTwoPassParsing() const;
 
     /** \param  flag true if wrapped lines receive unique line numbers.
      *  otherwise wrapped lines don't have line numbers at all. */
@@ -398,10 +406,17 @@ public:
     */
     void setPluginParameter ( const string& param );
 
+    void resetSyntaxReaders();
+    
     /** Load the Lua functions og the plug-in script
     	\param script path of the plug-in script
     */
     bool initPluginScript(const string& script);
+    
+    bool syntaxRequiresTwoPassRun();
+    
+    void clearPersistentSnippets();
+
 
     /** \return Syntaxreader Regex error message */
     string getSyntaxRegexError();
@@ -564,8 +579,8 @@ protected:
     string docTitle;
 
     string inFile,   ///< input file name
-           outFile; ///< output file name
-
+           outFile;  ///< output file name
+           
     /** Test if maskWsBegin and maskWsEnd should be applied */
     bool maskWs;
 
@@ -593,6 +608,8 @@ protected:
     /** Flag to output token of the same syntax category in separate tags */
     bool isolateTags;
     
+    bool disableStyleCache;
+    
     /** The base font to use */
     string baseFont ;
 
