@@ -31,6 +31,9 @@ std::string getAppPath();
 
 std::string getHomePath();
 
+std::string getTempFilePath();
+
+
 /** \param fileList Vector where found entries will be stored
     \param  wildcard Directory path and wildcard
     \param recursiveSearch Test if directory should be searched recursively */
@@ -45,6 +48,8 @@ int wildcmp ( const char *wild, const char *data );
 
 bool fileExists(const std::string &fName);
 
+off_t fileSize(const std::string& fName);
+
 int isColorEscCapable();
 
 }
