@@ -3,7 +3,7 @@
                              -------------------
     begin                : Son Nov 10 2002
     copyright            : (C) 2002-2010 by Andre Simon
-    email                : andre.simon1@gmx.de
+    email                : a.simon@mailbox.org
  ***************************************************************************/
 
 
@@ -61,14 +61,14 @@ private:
     ElementStyle canvas;
 
     string errorMsg;
-    string desc;
+    string desc, categories;
     string themeInjections;
         
     vector<Diluculum::LuaFunction*> pluginChunks;
 
-    bool fileOK;
+    bool fileOK, restoreStyles, dirtyAttributes;
 
-    KeywordStyles keywordStyles;
+    KeywordStyles keywordStyles, originalStyles;
 
     void initStyle(ElementStyle& style, const Diluculum::LuaVariable& var);
 
@@ -96,11 +96,16 @@ public:
     /** \return Font size */
     string getErrorMessage() const;
 
-    string getDescription() const
+    const string &getDescription() const
     {
         return desc;
     }
 
+    const string &getCategoryDescription() const
+    {
+        return categories;
+    }
+
     string getInjections() const;
 
     /** \return Background colour*/
@@ -149,6 +154,8 @@ public:
 
     /** \return True if language definition was found */
     bool found() const ;
+    
+    void overrideAttributes( vector<int>& attributes);
 };
 
 }
